Ricecooker API reference
========================
The detailed information for content developers (chef authors) is presented here:

.. toctree::
   :maxdepth: 1

   nodes
   files
   languages
   htmlapps
   exercises
   chefops
